==> haskell-http-download-0.2.0.0-298-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-download.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-download
version:              0.2.0.0
visibility:           public
id:                   http-download-0.2.0.0-LnvZZkrx80t4VQv8r4cwIv
key:                  http-download-0.2.0.0-LnvZZkrx80t4VQv8r4cwIv
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/http-download#readme
synopsis:             Verified downloads with retries
description:
    Higher level HTTP download APIs include verification of content and retries

category:             Development
abi:                  2eaca6487338e2daf0a2e0bc38ca4b58
exposed:              True
exposed-modules:      Network.HTTP.Download Network.HTTP.Download.Verified
hidden-modules:       Paths_http_download
import-dirs:          /usr/lib/ghc-9.0.1/site-local/http-download-0.2.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/http-download-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/http-download-0.2.0.0
hs-libraries:         HShttp-download-0.2.0.0-LnvZZkrx80t4VQv8r4cwIv
depends:
    base-4.15.0.0 base64-bytestring-1.2.0.1-CtEMJytMRvxImsCsB8sCpa
    bytestring-0.10.12.1 conduit-1.3.4.1-BLONhohY05o3DaB794imz5
    conduit-extra-1.3.5-IrEqOTG0YtZ998gc47gxHl
    cryptonite-0.29-4GXGeU7MBxS1kRd3fVjXlU
    cryptonite-conduit-0.2.2-GcLl0x3iAz784YqUydgiHm directory-1.3.6.1
    exceptions-0.10.4 filepath-1.4.2.1
    http-client-0.7.8-JF57Uz6k97nLmqDGQ4NJhe
    http-conduit-2.3.8-JW5fv7Sv3zWKCHnRiR4n8Y
    http-types-0.12.3-5OQIfWo1epLjmhOdBpvcY
    memory-0.16.0-CGaPOmXCTce28vOCDDnDFr
    path-0.9.0-62rPzBSuTrRHsdi1WAiYi5
    path-io-1.6.3-3qQzN5rv7vM5345SEKYq7d
    retry-0.8.1.2-2MEqfD89lvU2tjgvQ6kPFh
    rio-0.1.20.0-ByWzLPTHRVLBUddXzGrKYf
    rio-prettyprint-0.1.1.0-Jztr5eC7a6H1fPQNeX80wH

haddock-interfaces:
    /usr/share/doc/haskell-http-download/html/http-download.haddock

haddock-html:         /usr/share/doc/haskell-http-download/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-download-0.2.0.0-305-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-download.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-download
version:              0.2.0.0
visibility:           public
id:                   http-download-0.2.0.0-2lMRo7aZC4Y8XHtlyFDOXb
key:                  http-download-0.2.0.0-2lMRo7aZC4Y8XHtlyFDOXb
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/http-download#readme
synopsis:             Verified downloads with retries
description:
    Higher level HTTP download APIs include verification of content and retries

category:             Development
abi:                  88e9c430af2dd1fa1fd743acec440d7b
exposed:              True
exposed-modules:      Network.HTTP.Download Network.HTTP.Download.Verified
hidden-modules:       Paths_http_download
import-dirs:          /usr/lib/ghc-9.0.1/site-local/http-download-0.2.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/http-download-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/http-download-0.2.0.0
hs-libraries:         HShttp-download-0.2.0.0-2lMRo7aZC4Y8XHtlyFDOXb
depends:
    base-4.15.0.0 base64-bytestring-1.2.0.1-JzCUR1lvHkYGhV3JuhtpaC
    bytestring-0.10.12.1 conduit-1.3.4.1-KoylouIZ3WnLikf21al9kA
    conduit-extra-1.3.5-2MhLtrT31tPEF0HK8nyrj5
    cryptonite-0.29-QHgGFOBSTwHZpNTDIovh8
    cryptonite-conduit-0.2.2-CULmzFpjVZlGnuSUT9yztY directory-1.3.6.1
    exceptions-0.10.4 filepath-1.4.2.1
    http-client-0.7.8-EptQmwBg3o8F6RQqhSLxq3
    http-conduit-2.3.8-FSNiEtIJiys3JJLbPfmPWk
    http-types-0.12.3-AzIeHF2sXHG7NCAYxnjed8
    memory-0.16.0-CGaPOmXCTce28vOCDDnDFr
    path-0.9.0-7I7ZtmuqNu3J0UNKpe6Vjf
    path-io-1.6.3-CVaIeP8ug2Y7tnhjPQzmZx
    retry-0.9.0.0-LYFIwkPgxht9U2BYrmnp
    rio-0.1.20.0-1bpYgkGDjW5xFOJFnP1Ce
    rio-prettyprint-0.1.1.0-GAY0zEuFn8X4bFfXH462fZ

haddock-interfaces:
    /usr/share/doc/haskell-http-download/html/http-download.haddock

haddock-html:         /usr/share/doc/haskell-http-download/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
